@@ -15,7 +15,7 @@ if 'DUECREDIT_TEST_EARLY_IMPORT_ERROR' in os.environ.keys():
 import re
 import locale
 import time
-from collections import defaultdict, Iterator
+from collections import defaultdict
 import copy
 from os.path import dirname, exists
 import pickle
@@ -28,6 +28,7 @@ from time import sleep
 from .config import CACHE_DIR, DUECREDIT_FILE
 from .entries import BibTeX, Doi, Text, Url
 from .log import lgr
+from .versions import external_versions
 
 _PREFERRED_ENCODING = locale.getpreferredencoding()
 platform_system = platform.system().lower()
@@ -56,6 +57,7 @@ def import_doi(doi, sleep=0.5, retries=10):
     headers = {'Accept': 'application/x-bibtex; charset=utf-8'}
     url = 'https://doi.org/' + doi
     while retries > 0:
+        lgr.debug("Submitting GET to %s with headers %s", url, headers)
         r = requests.get(url, headers=headers)
         r.encoding = 'UTF-8'
         bibtex = r.text.strip()
@@ -310,8 +312,16 @@ def format_bibtex(bibtex_entry, style='harvard1'):
                 # we should be able to provide encoding argument
                 bib_source = cpBibTeX(fname, encoding='utf-8')
         except Exception as e:
-            lgr.error("Failed to process BibTeX file %s: %s" % (fname, e))
-            return "ERRORED: %s" % str(e)
+            msg = "Failed to process BibTeX file %s: %s." % (fname, e)
+            citeproc_version = external_versions['citeproc']
+            if 'unexpected keyword argument' in str(e) and \
+                    citeproc_version and citeproc_version < '0.4':
+                err = "need a newer citeproc-py >= 0.4.0"
+                msg += " You might just " + err
+            else:
+                err = str(e)
+            lgr.error(msg)
+            return "ERRORED: %s" % err
         finally:
             # return warnings back
             warnings.filters = old_filters
